Class: Aws::ApplicationCostProfiler::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ApplicationCostProfiler::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-applicationcostprofiler/client.rb
Overview
An API client for ApplicationCostProfiler. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ApplicationCostProfiler::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_report_definition(params = {}) ⇒ Types::DeleteReportDefinitionResult
Deletes the specified report definition in AWS Application Cost Profiler.
-
#get_report_definition(params = {}) ⇒ Types::GetReportDefinitionResult
Retrieves the definition of a report already configured in AWS Application Cost Profiler.
-
#import_application_usage(params = {}) ⇒ Types::ImportApplicationUsageResult
Ingests application usage data from Amazon Simple Storage Service (Amazon S3).
-
#list_report_definitions(params = {}) ⇒ Types::ListReportDefinitionsResult
Retrieves a list of all reports and their configurations for your AWS account.
-
#put_report_definition(params = {}) ⇒ Types::PutReportDefinitionResult
Creates the report definition for a report in Application Cost Profiler.
-
#update_report_definition(params = {}) ⇒ Types::UpdateReportDefinitionResult
Updates existing report in AWS Application Cost Profiler.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
762 763 764 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 762 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
765 766 767 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 765 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 735 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ApplicationCostProfiler') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-applicationcostprofiler' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_report_definition(params = {}) ⇒ Types::DeleteReportDefinitionResult
Deletes the specified report definition in AWS Application Cost Profiler. This stops the report from being generated.
501 502 503 504 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 501 def delete_report_definition(params = {}, = {}) req = build_request(:delete_report_definition, params) req.send_request() end |
#get_report_definition(params = {}) ⇒ Types::GetReportDefinitionResult
Retrieves the definition of a report already configured in AWS Application Cost Profiler.
543 544 545 546 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 543 def get_report_definition(params = {}, = {}) req = build_request(:get_report_definition, params) req.send_request() end |
#import_application_usage(params = {}) ⇒ Types::ImportApplicationUsageResult
Ingests application usage data from Amazon Simple Storage Service (Amazon S3).
The data must already exist in the S3 location. As part of the action, AWS Application Cost Profiler copies the object from your S3 bucket to an S3 bucket owned by Amazon for processing asynchronously.
580 581 582 583 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 580 def import_application_usage(params = {}, = {}) req = build_request(:import_application_usage, params) req.send_request() end |
#list_report_definitions(params = {}) ⇒ Types::ListReportDefinitionsResult
Retrieves a list of all reports and their configurations for your AWS account.
The maximum number of reports is one.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
628 629 630 631 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 628 def list_report_definitions(params = {}, = {}) req = build_request(:list_report_definitions, params) req.send_request() end |
#put_report_definition(params = {}) ⇒ Types::PutReportDefinitionResult
Creates the report definition for a report in Application Cost Profiler.
678 679 680 681 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 678 def put_report_definition(params = {}, = {}) req = build_request(:put_report_definition, params) req.send_request() end |
#update_report_definition(params = {}) ⇒ Types::UpdateReportDefinitionResult
Updates existing report in AWS Application Cost Profiler.
726 727 728 729 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 726 def update_report_definition(params = {}, = {}) req = build_request(:update_report_definition, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
755 756 757 |
# File 'lib/aws-sdk-applicationcostprofiler/client.rb', line 755 def waiter_names [] end |